@@ -19,7 +19,7 @@ def main():
         "Accept": "application/json",
         "Content-Type": "application/json",
     }
-    with open("Bling_api.csv", "r", encoding="utf-8") as f:
+    with open(settings.file_path, "r", encoding="utf-8") as f:
         csv_file = csv.reader(f, delimiter=";")
 
         for index, row in enumerate(csv_file):
